@@ -57,9 +57,9 @@ class BehaviorDict(dict):
         super(BehaviorDict, self).__setitem__(name, value)
         self.client.set_behaviors({name: value})
 
-    def update(self, *args, **kwds):
-        super(BehaviorDict, self).update(*args, **kwds)
-        self.client.set_behaviors(self.copy())
+    def update(self, d):
+        super(BehaviorDict, self).update(d)
+        self.client.set_behaviors(d.copy())
 
 class Client(_pylibmc.client):
     def __init__(self, servers, binary=False):
@@ -115,9 +115,9 @@ class Client(_pylibmc.client):
         This also happens for `distribution`.
         """
         behaviors = behaviors.copy()
-        if behaviors.get("hash", None) in hashers:
+        if behaviors.get("hash") is not None:
             behaviors["hash"] = hashers[behaviors["hash"]]
-        if behaviors.get("distribution") in distributions:
+        if behaviors.get("distribution") is not None:
             behaviors["distribution"] = distributions[behaviors["distribution"]]
         return super(Client, self).set_behaviors(behaviors)
 
@@ -192,7 +192,7 @@ class ThreadMappedPool(dict):
         Creates a new client based on the master client if none exists for the
         current thread.
         """
-        key = threading.current_thread().ident
+        key = thread.get_ident()
         mc = self.pop(key, None)
         if mc is None:
             mc = self.master.clone()
@@ -203,7 +203,7 @@ class ThreadMappedPool(dict):
 
 # This makes sure ThreadMappedPool doesn't exist with non-thread Pythons.
 try:
-    import threading
+    import thread
 except ImportError:
     del ThreadMappedPool
 
